@@ -448,7 +448,7 @@ class WOQLClient:
 
         return DispatchRequest.sendRequestByAction(idParser.docURL(), const.DELETE_DOCUMENT, key)
 
-    def select(self, woqlQuery, dbID=None, key=None,fileList=None):
+    def select(self, woqlQuery, dbID=None, key=None):
         """
         Executes a read-only WOQL query on the specified database and returns the results
 
@@ -465,22 +465,17 @@ class WOQLClient:
             self.conConfig.setDB(dbID)
 
         payload = {'terminus:query': json.dumps(woqlQuery)}
-        if type(fileList) == dict:
-            payload.update(fileList);
-
         return self.dispatch(self.conConfig.queryURL(), const.WOQL_SELECT, key, payload)
 
     @staticmethod
-    def directSelect(woqlQuery, dbURL, key, fileList=None):
+    def directSelect(woqlQuery, dbURL, key):
         idParser = IDParser()
         idParser.parseDBURL(dbURL)
 
         payload = {'terminus:query': json.dumps(woqlQuery)}
-        if type(fileList) == dict:
-            payload.update(fileList);
         return DispatchRequest.sendRequestByAction(idParser.queryURL(), const.WOQL_SELECT, key, payload)
 
-    def update(self, woqlQuery, dbID=None, key=None ,fileList=None):
+    def update(self, woqlQuery, dbID=None, key=None):
         """
         Executes a WOQL query on the specified database which updates the state and returns the results
 
@@ -493,42 +488,18 @@ class WOQLClient:
         if(dbID):
             self.conConfig.setDB(dbID)
             # raise InvalidURIError(ErrorMessage.getInvalidURIMessage(docurl, "Update"))
-        if type(fileList) == dict:
-            file_dict = {}
-            for name in fileList:
-                path = fileList[name]
-                stream = open(path, 'rb')
-                print(name)
-                file_dict[name] = (name,stream,'text/plain')
-            file_dict['terminus:query'] = (None,json.dumps(woqlQuery),'application/json')
-            payload = None
-        else:
-            file_dict = None
-            payload = {'terminus:query': json.dumps(woqlQuery)}
-
-        return self.dispatch(self.conConfig.queryURL(), const.WOQL_UPDATE, key, payload, file_dict)
+        payload = {'terminus:query': json.dumps(woqlQuery)}
+        return self.dispatch(self.conConfig.queryURL(), const.WOQL_UPDATE, key, payload)
 
     @staticmethod
-    def directUpdate(woqlQuery, dbURL, key,fileList=None):
+    def directUpdate(woqlQuery, dbURL, key):
         idParser = IDParser()
         idParser.parseDBURL(dbURL)
 
-        if type(fileList) == dict:
-            file_dict = {}
-            for name in fileList:
-                path = fileList[name]
-                stream = open(path, 'rb')
-                print(name)
-                file_dict[name] = (name,stream,'text/plain')
-            file_dict['terminus:query'] = (None,json.dumps(woqlQuery),'application/json')
-            payload = None
-        else:
-            file_dict = None
-            payload = {'terminus:query': json.dumps(woqlQuery)}
+        payload = {'terminus:query': json.dumps(woqlQuery)}
+        return DispatchRequest.sendRequestByAction(idParser.queryURL(), const.WOQL_UPDATE, key, payload)
 
-        return DispatchRequest.sendRequestByAction(idParser.queryURL(), const.WOQL_UPDATE, key, payload, file_dict)
-
-    def dispatch(self, url, action, connectionKey, payload={}, file_dict = None):
+    def dispatch(self, url, action, connectionKey, payload={}):
         if connectionKey is None:
             # if the api key is not setted the method raise an APIerror
             connectionKey = self.conCapabilities.getClientKey()
@@ -542,4 +513,4 @@ class WOQLClient:
         #check if we can perform this action or raise an AccessDeniedError error
         #review the access control
         #self.conCapabilities.capabilitiesPermit(action)
-        return DispatchRequest.sendRequestByAction(url, action, connectionKey, payload, file_dict)
+        return DispatchRequest.sendRequestByAction(url, action, connectionKey, payload)
